@@ -184,8 +184,13 @@ class RegularTileAccessIterator<
 
     char *access_byte_ptr =
         reinterpret_cast<char *>(access_ptr + access_offset);
+    if ((threadIdx.x == 0) && (blockIdx.x == 0) && (blockIdx.y == 0) && (blockIdx.z == 0)) {
+        printf("Congruous, tidx = %d, ts kContiguous = %d\n", threadIdx.x, Layout::TileShape::kContiguous);
+        printf("Congruous, tidx = %d, tm kStrided = %d\n", threadIdx.x, ThreadMap::Delta::kStrided);
+        printf("Congruous, tidx = %d, tm kContiguous = %d\n", threadIdx.x, ThreadMap::Delta::kContiguous);
+    }
     if (((threadIdx.x / 32 == 0)) && (blockIdx.x == 0) && (blockIdx.y == 0) && (blockIdx.z == 0)) {
-        printf("Congruous, tidx = %d, access_ptr = 0x%p, stride_idx = %d, access_offset = %d, access_byte_ptr = 0x%p\n", threadIdx.x, access_ptr, stride_idx, access_offset, access_byte_ptr);
+        printf("Congruous, tidx = %d, access_ptr = 0x%p, stride_idx = %d, stride_ = %d, it_stride = %d, it_cont = %d, access_offset = %d, access_byte_ptr = 0x%p\n", threadIdx.x, access_ptr, stride_idx, stride_, iteration_strided_, iteration_contiguous_, access_offset, access_byte_ptr);
     }
     return reinterpret_cast<AccessType *>(access_byte_ptr + byte_offset_);
   }
@@ -587,7 +592,7 @@ class RegularTileAccessIterator<Shape_, Element_,
         printf("Crosswise, tidx = %d, tm kContiguous = %d\n", threadIdx.x, ThreadMap::Delta::kContiguous);
     }
     if ((threadIdx.x / 32 == 0) && (blockIdx.x == 0) && (blockIdx.y == 0) && (blockIdx.z == 0)) {
-        printf("Crosswise, tidx = %d, access_ptr = 0x%p, stride_idx = %d, stride_ = %d, access_offset = %d, access_byte_ptr = 0x%p\n", threadIdx.x, access_ptr, stride_idx, stride_, access_offset, access_byte_ptr);
+        printf("Crosswise, tidx = %d, access_ptr = 0x%p, stride_idx = %d, stride_ = %d, it_stride = %d, it_cont = %d, access_offset = %d, access_byte_ptr = 0x%p\n", threadIdx.x, access_ptr, stride_idx, stride_, iteration_strided_, iteration_contiguous_, access_offset, access_byte_ptr);
     }
     return reinterpret_cast<AccessType *>(access_byte_ptr + byte_offset_);
   }
